run_operator

Function run_operator 

pub fn run_operator(config: OperatorConfig, handler: impl Handler) -> Error
Starts the operator and blocks the current thread indefinitely until the operator shuts down due to an error.