pub enum Credentials {
Header(String),
Pem {
certificate_base64: String,
private_key_base64: String,
},
PemPath {
certificate_path: String,
private_key_path: String,
},
}Expand description
Represents how to authenticate to the cluster. Roperator supports either using an Authorization header
or a public/private key pair. The Header value can support either username/password or token based
authentication.
Variants
Header(String)
Represents the value to set for an Authorization header. This value must include the prefix (e.g. Basic
or Bearer ) as well as the properly encoded and formatted value.
Pem
Values for authenticating using a certificate. This is frequently used in kubeconfig files
Fields
PemPath
Implementations
Sourceimpl Credentials
impl Credentials
Sourcepub fn raw_bearer_token(raw_token: impl AsRef<str>) -> Credentials
pub fn raw_bearer_token(raw_token: impl AsRef<str>) -> Credentials
Creates a Credentials from a raw (not base64 encoded) token
Sourcepub fn base64_bearer_token(base64_token: impl AsRef<str>) -> Credentials
pub fn base64_bearer_token(base64_token: impl AsRef<str>) -> Credentials
Creates a Credentials from a token that is already base64 encoded