pub fn run_operator(config: OperatorConfig, handler: impl Handler) -> ErrorExpand description
Starts the operator and blocks the current thread indefinitely until the operator shuts down due to an error.
pub fn run_operator(config: OperatorConfig, handler: impl Handler) -> ErrorStarts the operator and blocks the current thread indefinitely until the operator shuts down due to an error.